@@ -167,7 +167,21 @@ class CloudFrontToS3(
         :summary: Constructs a new instance of the CloudFrontToS3 class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudFrontToS3.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                cloud_front_distribution_props: typing.Any = None,
+                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                insert_http_security_headers: typing.Optional[builtins.bool] = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+                origin_path: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontToS3Props(
@@ -260,7 +274,19 @@ class CloudFrontToS3Props:
         if isinstance(logging_bucket_props, dict):
             logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if __debug__:
-            type_hints = typing.get_type_hints(CloudFrontToS3Props.__init__)
+            def stub(
+                *,
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                cloud_front_distribution_props: typing.Any = None,
+                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                insert_http_security_headers: typing.Optional[builtins.bool] = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+                origin_path: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
             check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
             check_type(argname="argument cloud_front_logging_bucket_props", value=cloud_front_logging_bucket_props, expected_type=type_hints["cloud_front_logging_bucket_props"])
